@@ -8,8 +8,8 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.AccelGroup;
 import org.gnu.gtk.Container;
@@ -20,6 +20,7 @@ import org.gnu.gtk.ToolBar;
 import org.gnu.gtk.VBox;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.Window;
+import org.gnu.javagnome.Handle;
 
 /**
  * The App widget is the main window of a GNOME application. It is
@@ -78,8 +79,7 @@ public class App extends Window {
 	}
 	
 	/**
-	 * Returns the contents of the App
-	 * @return
+	 * Returns the contents of the App.
 	 */
 	public Widget getContents() {
 		Handle hndl = getContents(getHandle());
@@ -142,8 +142,8 @@ public class App extends Window {
 	/**
 	 * If true, the application uses gnome-config to retrieve and save the
 	 * docking configuration automatically.
-	 * @param enable True if the docking configuration is to be handled
-	 *               automatically, else false.
+	 * @param enabled True if the docking configuration is to be handled
+	 *                automatically, else false.
 	 */
 	public void layoutConfig(boolean enabled) {
 		gnome_app_enable_layout_config(getHandle(), enabled);
@@ -354,6 +354,7 @@ public class App extends Window {
 	 * @param message The text to display.
 	 * @return The dialog created or null.
 	 * @deprecated
+	 * @see org.gnu.gtk.MessageDialog
 	 */
 	public Widget message(String message) {
 		Handle hndl = gnome_app_message(getHandle(), message);
@@ -380,6 +381,7 @@ public class App extends Window {
 	 * @param warning The text to display.
 	 * @return The dialog created or null.
 	 * @deprecated
+	 * @see org.gnu.gtk.MessageDialog
 	 */
 	public Widget warning(String warning) {
 		Handle hndl = gnome_app_warning(getHandle(), warning);
@@ -396,6 +398,7 @@ public class App extends Window {
 	 * @param error The text to display.
 	 * @return The dialog created or null.
 	 * @deprecated
+	 * @see org.gnu.gtk.MessageDialog
 	 */
 	public Widget error(String error) {
 		Handle hndl = gnome_app_error(getHandle(), error);
@@ -433,16 +436,16 @@ public class App extends Window {
 	native static final protected void gnome_app_set_contents(Handle app, Handle contents);
 	native static final protected void gnome_app_enable_layout_config(Handle app, boolean enable);
 	native static final protected void gnome_app_fill_menu(Handle menuShell, Handle[] uiInfo, Handle accelGroup, boolean ulineAccels, int pos);
-	native static final protected void gnome_app_fill_menu_with_data(Handle menuShell, Handle uiInfo, Handle accelGroup, boolean ulineAccels, int pos, Object userData);
-	native static final protected void gnome_app_fill_menu_custom(Handle menuShell, Handle uiInfo, Handle uiBData, Handle accelGroup, boolean ulineAccels, int pos);
+	native static final protected void gnome_app_fill_menu_with_data(Handle menuShell, Handle[] uiInfo, Handle accelGroup, boolean ulineAccels, int pos, Object userData);
+	native static final protected void gnome_app_fill_menu_custom(Handle menuShell, Handle[] uiInfo, Handle uiBData, Handle accelGroup, boolean ulineAccels, int pos);
 	native static final protected void gnome_app_ui_configure_configurable(Handle uiinfo);
 	native static final protected void gnome_app_create_menus(Handle app, Handle[] uiinfo);
-	native static final protected void gnome_app_create_menus_custom(Handle app, Handle uiinfo, Handle uibdate);
+	native static final protected void gnome_app_create_menus_custom(Handle app, Handle[] uiinfo, Handle uibdate);
 	native static final protected void gnome_app_create_toolbar(Handle app, Handle[] uiinfo);
-	native static final protected void gnome_app_create_toolbar_custom(Handle app, Handle uiinfo, Handle uibdata);
+	native static final protected void gnome_app_create_toolbar_custom(Handle app, Handle[] uiinfo, Handle uibdata);
 	native static final protected void gnome_app_fill_toolbar(Handle toolbar, Handle[] uiInfo, Handle accelGroup);
-	native static final protected void gnome_app_fill_toolbar_with_data(Handle toolbar, Handle uiInfo, Handle accelGroup, Object userData);
-	native static final protected void gnome_app_fill_toolbar_custom(Handle toolbar, Handle uiInfo, int uiBData, Handle accelGroup);
+	native static final protected void gnome_app_fill_toolbar_with_data(Handle toolbar, Handle[] uiInfo, Handle accelGroup, Object userData);
+	native static final protected void gnome_app_fill_toolbar_custom(Handle toolbar, Handle[] uiInfo, int uiBData, Handle accelGroup);
 	native static final protected int gnome_app_find_menu_pos(Handle parent, String path, int pos);
 	native static final protected void gnome_app_remove_menus(Handle app, String path, int items);
 	native static final protected void gnome_app_remove_menu_range(Handle app, String path, int start, int items);
