@@ -8,7 +8,10 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.Type;
+import org.gnu.javagnome.Handle;
+
 /**
  *
  */
@@ -17,13 +20,10 @@ public class CanvasClipgroup extends CanvasGroup {
 	 * Constructs an instance of CanvasClipgroup from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasClipgroup(int handle) {
+	CanvasClipgroup(Handle handle) {
 		super(handle);
 	}
 
-	protected void noopInit() {
-	}
-
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -31,11 +31,7 @@ public class CanvasClipgroup extends CanvasGroup {
 		return new Type(gnome_canvas_clipgroup_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_canvas_clipgroup_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
