@@ -8,16 +8,25 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.Type;
+import org.gnu.javagnome.Handle;
+
 /**
  *
  */
 public class CanvasPixbuf extends CanvasItem {
+
+	public CanvasPixbuf(CanvasGroup group) {
+		super(group, gnome_canvas_pixbuf_get_type());
+	}
+
+	
 	/**
 	 * Constructs an instance of CanvasPixbuf from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasPixbuf(int handle) {
+	CanvasPixbuf(Handle handle) {
 		super(handle);
 	}
 
@@ -28,11 +37,6 @@ public class CanvasPixbuf extends CanvasItem {
 		return new Type(gnome_canvas_pixbuf_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
 	native static final protected int gnome_canvas_pixbuf_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
