@@ -8,13 +8,15 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.Button;
 import org.gnu.gtk.Container;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.Window;
+import org.gnu.javagnome.Handle;
+
 /**
  * The GNOME druid is a system for assisting the user with installing a
  * service. It is roughly equivalent in functionality to the Wizards
@@ -110,7 +112,7 @@ public class Druid extends Container {
 	 */
 	public Button getHelpButton() {
 		Handle hndl = getHelp(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Button)obj;
 		return new Button(hndl);
@@ -121,7 +123,7 @@ public class Druid extends Container {
 	 */
 	public Button getBackButton() {
 		Handle hndl = getBack(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Button)obj;
 		return new Button(hndl);
@@ -132,7 +134,7 @@ public class Druid extends Container {
 	 */
 	public Button getNextButton() {
 		Handle hndl = getNext(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Button)obj;
 		return new Button(hndl);
@@ -143,7 +145,7 @@ public class Druid extends Container {
 	 */
 	public Button getCancelButton() {
 		Handle hndl = getCancel(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Button)obj;
 		return new Button(hndl);
@@ -154,7 +156,7 @@ public class Druid extends Container {
 	 */
 	public Button getFinishButton() {
 		Handle hndl = getFinish(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Button)obj;
 		return new Button(hndl);
