@@ -8,9 +8,11 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Handle;
+
 import org.gnu.glib.Type;
 import org.gnu.gtk.Button;
+import org.gnu.javagnome.Handle;
+
 /**
  * The HRef widget displays a frameless button that, when
  * selected, issues a command for the web browser to connect to a web
