@@ -8,12 +8,11 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Enum;
+
+import org.gnu.javagnome.Enum;
+
 public class HelpError extends Enum 
 {
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     static final private int _INTERNAL = 0;
     static final public org.gnu.gnome.HelpError INTERNAL = new org.gnu.gnome.HelpError (_INTERNAL);
     static final private int _NOT_FOUND = 1;
@@ -21,9 +20,7 @@ public class HelpError extends Enum
     static final private org.gnu.gnome.HelpError[] theInterned = new org.gnu.gnome.HelpError[] 
     {
         INTERNAL, NOT_FOUND 
-    }
-
-;
+    };
     static private java.util.Hashtable theInternedExtras;
     static final private org.gnu.gnome.HelpError theSacrificialOne = new org.gnu.gnome.HelpError (0);
     static public org.gnu.gnome.HelpError intern (int value) 
@@ -72,8 +69,5 @@ public class HelpError extends Enum
         return (value_ & other.value_) == other.value_;
     }
 
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
 }
 
