@@ -8,12 +8,16 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Handle;
+
 import org.gnu.glib.Type;
 import org.gnu.gtk.Dialog;
+import org.gnu.javagnome.Handle;
+
 /**
  * The GnomeScores widget displays a list of names and scores for the
  * players of a game.
+ * 
+ * @deprecated
  */
 public class Scores extends Dialog {
 	/**
